{
  am_pm_abbreviated => [
    "tifawt",
    "tadgg\N{U+02b7}at",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "shi-Latn-MA",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "ayn",
    "asi",
    "ak\N{U+1e5b}",
    "akw",
    "asim",
    "asi\N{U+1e0d}",
    "asa",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "aynas",
    "asinas",
    "ak\N{U+1e5b}as",
    "akwas",
    "asimwas",
    "asi\N{U+1e0d}yas",
    "asamas",
  ],
  day_stand_alone_abbreviated => [
    "ayn",
    "asi",
    "ak\N{U+1e5b}",
    "akw",
    "asim",
    "asi\N{U+1e0d}",
    "asa",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "aynas",
    "asinas",
    "ak\N{U+1e5b}as",
    "akwas",
    "asimwas",
    "asi\N{U+1e0d}yas",
    "asamas",
  ],
  era_abbreviated => [
    "da\N{U+025b}",
    "df\N{U+025b}",
  ],
  era_narrow => [
    "da\N{U+025b}",
    "df\N{U+025b}",
  ],
  era_wide => [
    "dat n \N{U+025b}isa",
    "dffir n \N{U+025b}isa",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tachelhit",
  month_format_abbreviated => [
    "inn",
    "b\N{U+1e5b}a",
    "ma\N{U+1e5b}",
    "ibr",
    "may",
    "yun",
    "yul",
    "\N{U+0263}uc",
    "cut",
    "ktu",
    "nuw",
    "duj",
  ],
  month_format_narrow => [
    "i",
    "b",
    "m",
    "i",
    "m",
    "y",
    "y",
    "\N{U+0263}",
    "c",
    "k",
    "n",
    "d",
  ],
  month_format_wide => [
    "innayr",
    "b\N{U+1e5b}ay\N{U+1e5b}",
    "ma\N{U+1e5b}\N{U+1e63}",
    "ibrir",
    "mayyu",
    "yunyu",
    "yulyuz",
    "\N{U+0263}uct",
    "cutanbir",
    "ktubr",
    "nuwanbir",
    "dujanbir",
  ],
  month_stand_alone_abbreviated => [
    "inn",
    "b\N{U+1e5b}a",
    "ma\N{U+1e5b}",
    "ibr",
    "may",
    "yun",
    "yul",
    "\N{U+0263}uc",
    "cut",
    "ktu",
    "nuw",
    "duj",
  ],
  month_stand_alone_narrow => [
    "i",
    "b",
    "m",
    "i",
    "m",
    "y",
    "y",
    "\N{U+0263}",
    "c",
    "k",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "innayr",
    "b\N{U+1e5b}ay\N{U+1e5b}",
    "ma\N{U+1e5b}\N{U+1e63}",
    "ibrir",
    "mayyu",
    "yunyu",
    "yulyuz",
    "\N{U+0263}uct",
    "cutanbir",
    "ktubr",
    "nuwanbir",
    "dujanbir",
  ],
  name => "Tachelhit Morocco Latin",
  native_language => "Tashel\N{U+1e25}iyt",
  native_name => "Tashel\N{U+1e25}iyt lm\N{U+0263}rib Latn",
  native_script => "Latn",
  native_territory => "lm\N{U+0263}rib",
  native_variant => undef,
  quarter_format_abbreviated => [
    "ak 1",
    "ak 2",
    "ak 3",
    "ak 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "ak\N{U+1e5b}a\N{U+1e0d}yur 1",
    "ak\N{U+1e5b}a\N{U+1e0d}yur 2",
    "ak\N{U+1e5b}a\N{U+1e0d}yur 3",
    "ak\N{U+1e5b}a\N{U+1e0d}yur 4",
  ],
  quarter_stand_alone_abbreviated => [
    "ak 1",
    "ak 2",
    "ak 3",
    "ak 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "ak\N{U+1e5b}a\N{U+1e0d}yur 1",
    "ak\N{U+1e5b}a\N{U+1e0d}yur 2",
    "ak\N{U+1e5b}a\N{U+1e0d}yur 3",
    "ak\N{U+1e5b}a\N{U+1e0d}yur 4",
  ],
  script => "Latin",
  territory => "Morocco",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
