{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMM => "LLLL y G",
    GyMMMMEd => "E, d MMMM y G",
    GyMMMMd => "d MMMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d.MM.y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-few" => "LLLL, 'tydz'. W",
    "MMMMW-count-many" => "LLLL, 'tydz'. W",
    "MMMMW-count-one" => "LLLL, 'tydz'. W",
    "MMMMW-count-other" => "LLLL, 'tydz'. W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d.MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E, d.MM.y",
    yMMM => "LLL y",
    yMMMEd => "E, d MMM y",
    yMMMM => "LLLL y",
    yMMMMEd => "E, d MMMM y",
    yMMMMd => "d MMMM y",
    yMMMd => "d MMM y",
    yMd => "d.MM.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "Y, 'tydz'. w",
    "yw-count-many" => "Y, 'tydz'. w",
    "yw-count-one" => "Y, 'tydz'. w",
    "yw-count-other" => "Y, 'tydz'. w",
  },
  code => "pl-PL",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "pon.",
    "wt.",
    "\N{U+015b}r.",
    "czw.",
    "pt.",
    "sob.",
    "niedz.",
  ],
  day_format_narrow => [
    "p",
    "w",
    "\N{U+015b}",
    "c",
    "p",
    "s",
    "n",
  ],
  day_format_wide => [
    "poniedzia\N{U+0142}ek",
    "wtorek",
    "\N{U+015b}roda",
    "czwartek",
    "pi\N{U+0105}tek",
    "sobota",
    "niedziela",
  ],
  day_stand_alone_abbreviated => [
    "pon.",
    "wt.",
    "\N{U+015b}r.",
    "czw.",
    "pt.",
    "sob.",
    "niedz.",
  ],
  day_stand_alone_narrow => [
    "P",
    "W",
    "\N{U+015a}",
    "C",
    "P",
    "S",
    "N",
  ],
  day_stand_alone_wide => [
    "poniedzia\N{U+0142}ek",
    "wtorek",
    "\N{U+015b}roda",
    "czwartek",
    "pi\N{U+0105}tek",
    "sobota",
    "niedziela",
  ],
  era_abbreviated => [
    "p.n.e.",
    "n.e.",
  ],
  era_narrow => [
    "p.n.e.",
    "n.e.",
  ],
  era_wide => [
    "przed nasz\N{U+0105} er\N{U+0105}",
    "naszej ery",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a, %-d %b %Y, %T %Z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a, %-d %b %Y, %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Polish",
  month_format_abbreviated => [
    "sty",
    "lut",
    "mar",
    "kwi",
    "maj",
    "cze",
    "lip",
    "sie",
    "wrz",
    "pa\N{U+017a}",
    "lis",
    "gru",
  ],
  month_format_narrow => [
    "s",
    "l",
    "m",
    "k",
    "m",
    "c",
    "l",
    "s",
    "w",
    "p",
    "l",
    "g",
  ],
  month_format_wide => [
    "stycznia",
    "lutego",
    "marca",
    "kwietnia",
    "maja",
    "czerwca",
    "lipca",
    "sierpnia",
    "wrze\N{U+015b}nia",
    "pa\N{U+017a}dziernika",
    "listopada",
    "grudnia",
  ],
  month_stand_alone_abbreviated => [
    "sty",
    "lut",
    "mar",
    "kwi",
    "maj",
    "cze",
    "lip",
    "sie",
    "wrz",
    "pa\N{U+017a}",
    "lis",
    "gru",
  ],
  month_stand_alone_narrow => [
    "S",
    "L",
    "M",
    "K",
    "M",
    "C",
    "L",
    "S",
    "W",
    "P",
    "L",
    "G",
  ],
  month_stand_alone_wide => [
    "stycze\N{U+0144}",
    "luty",
    "marzec",
    "kwiecie\N{U+0144}",
    "maj",
    "czerwiec",
    "lipiec",
    "sierpie\N{U+0144}",
    "wrzesie\N{U+0144}",
    "pa\N{U+017a}dziernik",
    "listopad",
    "grudzie\N{U+0144}",
  ],
  name => "Polish Poland",
  native_language => "polski",
  native_name => "polski Polska",
  native_script => undef,
  native_territory => "Polska",
  native_variant => undef,
  quarter_format_abbreviated => [
    "I kw.",
    "II kw.",
    "III kw.",
    "IV kw.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "I kwarta\N{U+0142}",
    "II kwarta\N{U+0142}",
    "III kwarta\N{U+0142}",
    "IV kwarta\N{U+0142}",
  ],
  quarter_stand_alone_abbreviated => [
    "I kw.",
    "II kw.",
    "III kw.",
    "IV kw.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "I kwarta\N{U+0142}",
    "II kwarta\N{U+0142}",
    "III kwarta\N{U+0142}",
    "IV kwarta\N{U+0142}",
  ],
  script => undef,
  territory => "Poland",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
