{
  am_pm_abbreviated => [
    "TOO",
    "MUU",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "lag-TZ",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "T\N{U+00e1}atu",
    "\N{U+00cd}ne",
    "T\N{U+00e1}ano",
    "Alh",
    "Ijm",
    "M\N{U+00f3}osi",
    "P\N{U+00ed}ili",
  ],
  day_format_narrow => [
    "T",
    "E",
    "O",
    "A",
    "I",
    "M",
    "P",
  ],
  day_format_wide => [
    "Jumat\N{U+00e1}tu",
    "Juma\N{U+00ed}ne",
    "Jumat\N{U+00e1}ano",
    "Alam\N{U+00ed}isi",
    "Ijum\N{U+00e1}a",
    "Jumam\N{U+00f3}osi",
    "Jumap\N{U+00ed}iri",
  ],
  day_stand_alone_abbreviated => [
    "T\N{U+00e1}atu",
    "\N{U+00cd}ne",
    "T\N{U+00e1}ano",
    "Alh",
    "Ijm",
    "M\N{U+00f3}osi",
    "P\N{U+00ed}ili",
  ],
  day_stand_alone_narrow => [
    "T",
    "E",
    "O",
    "A",
    "I",
    "M",
    "P",
  ],
  day_stand_alone_wide => [
    "Jumat\N{U+00e1}tu",
    "Juma\N{U+00ed}ne",
    "Jumat\N{U+00e1}ano",
    "Alam\N{U+00ed}isi",
    "Ijum\N{U+00e1}a",
    "Jumam\N{U+00f3}osi",
    "Jumap\N{U+00ed}iri",
  ],
  era_abbreviated => [
    "KSA",
    "KA",
  ],
  era_narrow => [
    "KSA",
    "KA",
  ],
  era_wide => [
    "K\N{U+0268}r\N{U+0268}sit\N{U+0289} s\N{U+0268} anavyaal",
    "K\N{U+0268}r\N{U+0268}sit\N{U+0289} akavyaalwe",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Langi",
  month_format_abbreviated => [
    "F\N{U+00fa}ngat\N{U+0268}",
    "Naan\N{U+0268}",
    "Keenda",
    "Ik\N{U+00fa}mi",
    "Inyambala",
    "Idwaata",
    "M\N{U+0289}\N{U+0289}nch\N{U+0268}",
    "V\N{U+0268}\N{U+0268}r\N{U+0268}",
    "Saat\N{U+0289}",
    "Inyi",
    "Saano",
    "Sasat\N{U+0289}",
  ],
  month_format_narrow => [
    "F",
    "N",
    "K",
    "I",
    "I",
    "I",
    "M",
    "V",
    "S",
    "I",
    "S",
    "S",
  ],
  month_format_wide => [
    "K\N{U+0289}f\N{U+00fa}ngat\N{U+0268}",
    "K\N{U+0289}naan\N{U+0268}",
    "K\N{U+0289}keenda",
    "Kwiikumi",
    "Kwiinyamb\N{U+00e1}la",
    "Kwiidwaata",
    "K\N{U+0289}m\N{U+0289}\N{U+0289}nch\N{U+0268}",
    "K\N{U+0289}v\N{U+0268}\N{U+0268}r\N{U+0268}",
    "K\N{U+0289}saat\N{U+0289}",
    "Kwiinyi",
    "K\N{U+0289}saano",
    "K\N{U+0289}sasat\N{U+0289}",
  ],
  month_stand_alone_abbreviated => [
    "F\N{U+00fa}ngat\N{U+0268}",
    "Naan\N{U+0268}",
    "Keenda",
    "Ik\N{U+00fa}mi",
    "Inyambala",
    "Idwaata",
    "M\N{U+0289}\N{U+0289}nch\N{U+0268}",
    "V\N{U+0268}\N{U+0268}r\N{U+0268}",
    "Saat\N{U+0289}",
    "Inyi",
    "Saano",
    "Sasat\N{U+0289}",
  ],
  month_stand_alone_narrow => [
    "F",
    "N",
    "K",
    "I",
    "I",
    "I",
    "M",
    "V",
    "S",
    "I",
    "S",
    "S",
  ],
  month_stand_alone_wide => [
    "K\N{U+0289}f\N{U+00fa}ngat\N{U+0268}",
    "K\N{U+0289}naan\N{U+0268}",
    "K\N{U+0289}keenda",
    "Kwiikumi",
    "Kwiinyamb\N{U+00e1}la",
    "Kwiidwaata",
    "K\N{U+0289}m\N{U+0289}\N{U+0289}nch\N{U+0268}",
    "K\N{U+0289}v\N{U+0268}\N{U+0268}r\N{U+0268}",
    "K\N{U+0289}saat\N{U+0289}",
    "Kwiinyi",
    "K\N{U+0289}saano",
    "K\N{U+0289}sasat\N{U+0289}",
  ],
  name => "Langi Tanzania",
  native_language => "K\N{U+0268}laangi",
  native_name => "K\N{U+0268}laangi Taansan\N{U+00ed}a",
  native_script => undef,
  native_territory => "Taansan\N{U+00ed}a",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Ncho 1",
    "Ncho 2",
    "Ncho 3",
    "Ncho 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Ncholo ya 1",
    "Ncholo ya 2",
    "Ncholo ya 3",
    "Ncholo ya 4",
  ],
  quarter_stand_alone_abbreviated => [
    "Ncho 1",
    "Ncho 2",
    "Ncho 3",
    "Ncho 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Ncholo ya 1",
    "Ncholo ya 2",
    "Ncholo ya 3",
    "Ncholo ya 4",
  ],
  script => undef,
  territory => "Tanzania",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
